@@ -22,7 +22,6 @@
 #ifndef __GDLContentStore_GCSFolderManager_H__
 #define __GDLContentStore_GCSFolderManager_H__
 
-#import <Foundation/NSObject.h>
 
 /*
   GCSFolderManager
@@ -32,22 +31,35 @@
 */
 
 @class NSString, NSArray, NSURL, NSDictionary, NSException;
-@class GCSChannelManager, GCSAlarmsFolder, GCSFolder, GCSFolderType, GCSSessionsFolder;
+@class GCSChannelManager, GCSAlarmsFolder, GCSAdminFolder, GCSFolder, GCSFolderType, GCSSessionsFolder;
 
 @interface GCSFolderManager : NSObject
 {
   GCSChannelManager *channelManager;
   NSDictionary      *nameToType;
   NSURL             *folderInfoLocation;
+  NSURL             *storeLocation;
+  NSURL             *aclLocation;
+  NSURL             *cacheFolderLocation;
 }
 
++ (BOOL) singleStoreMode;
 + (id)defaultFolderManager;
-- (id)initWithFolderInfoLocation:(NSURL *)_url;
+- (id)initWithFolderInfoLocation: (NSURL *)_infoUrl 
+                andStoreLocation: (NSURL *)_storeUrl
+                  andAclLocation: (NSURL *)_aclUrl
+	  andCacheFolderLocation: (NSURL *)_cacheFolderUrl;
 
 /* accessors */
 
 - (NSURL *)folderInfoLocation;
 - (NSString *)folderInfoTableName;
+- (NSURL *)storeLocation;
+- (NSString *)storeTableName;
+- (NSURL *)aclLocation;
+- (NSString *)aclTableName;
+- (NSURL *)cacheFolderLocation;
+- (NSString *)cacheFolderTableName;
 
 /* connection */
 
@@ -65,6 +77,7 @@
 - (BOOL)folderExistsAtPath:(NSString *)_path;
 - (NSArray *)listSubFoldersAtPath:(NSString *)_path recursive:(BOOL)_flag;
 
+- (NSDictionary *) recordAtPath: (NSString *) _path;
 - (GCSFolder *)folderAtPath:(NSString *)_path;
 
 - (NSException *)createFolderOfType:(NSString *)_type withName:(NSString *)_name atPath:(NSString *)_path;
@@ -76,6 +89,9 @@
 /* sessions */
 - (GCSSessionsFolder *)sessionsFolder;
 
+/* admin */
+- (GCSAdminFolder *)adminFolder;
+
 /* folder types */
 
 - (GCSFolderType *)folderTypeWithName:(NSString *)_name;
