@@ -36,7 +36,6 @@
         route later, we can still do it :-)
 */
 
-#import <Foundation/NSObject.h>
 
 @class NSString, NSArray, NSDictionary;
 @class EOQualifier;
@@ -53,6 +52,7 @@
 }
 
 + (id)folderTypeWithName:(NSString *)_type;
++ (id)folderTypeWithName:(NSString *)_type  driver:(NSString *)_driver;
 
 - (id)initWithPropertyList:(id)_plist;
 - (id)initWithContentsOfFile:(NSString *)_path;
