@@ -29,6 +29,10 @@
 
 - (id) objectForCaseInsensitiveKey: (NSString *) aKey;
 
+- (void) versitRenderInString: (NSMutableString *) aString
+              withKeyOrdering: (NSArray *) ordering
+                 asAttributes: (BOOL) asAttribute; /* handling of ":" */
+
 @end
 
 #endif /* NSDICTIONARY_NGCARDS_H */
