@@ -27,20 +27,21 @@
 
 @class NSArray;
 @class NSCalendarDate;
+@class NSMutableDictionary;
 @class NSTimeZone;
 
 @interface NSString (NGCardsExtensions)
 
 - (NSString *) foldedForVersitCards;
 - (NSArray *) asCardAttributeValues;
-- (NSString *) escapedForCards;
+- (NSString *) escapedForCardsAsAttributes: (BOOL) asAttributes;
 - (NSString *) rfc822Email;
 
 - (NSTimeInterval) durationAsTimeInterval;
 - (NSCalendarDate *) asCalendarDate;
 - (BOOL) isAllDayDate;
 
-- (NSArray *) vCardSubvaluesWithSeparator: (unichar) separator;
+- (NSMutableDictionary *) vCardSubvalues;
 
 @end
 
