@@ -38,18 +38,6 @@
 @class iCalTimeZone;
 
 @interface iCalCalendar : CardGroup
-// {
-//   NSString *version;
-//   NSString *calscale;
-//   NSString *prodId;
-//   NSString *method;
-
-//   NSMutableArray *todos;
-//   NSMutableArray *events;
-//   NSMutableArray *journals;
-//   NSMutableArray *freeBusys;
-//   NSMutableDictionary *timezones;
-// }
 
 /* accessors */
 
@@ -68,12 +56,16 @@
 - (void) setMethod: (NSString *) _method;
 - (NSString *) method;
 
+- (NSCalendarDate *) startDate;
+
 - (NSArray *) events;
 - (NSArray *) todos;
 - (NSArray *) journals;
 - (NSArray *) freeBusys;
 - (NSArray *) timezones;
 
+- (void) addToEvents: (iCalEvent *) _event;
+
 - (BOOL) addTimeZone: (iCalTimeZone *) iTZ;
 - (iCalTimeZone *) timeZoneWithId: (NSString *) tzId;
 
