@@ -1,6 +1,6 @@
 /* NSString+Utilities.h - this file is part of SOGo
  *
- * Copyright (C) 2006-2015 Inverse inc.
+ * Copyright (C) 2006-2022 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #define NSSTRING_URL_H
 
 #import <Foundation/NSString.h>
+#import <Foundation/NSRegularExpression.h>
 
 @class NSCharacterSet;
 @class NSDictionary;
@@ -51,6 +52,7 @@
 
 /* SQL safety */
 - (NSString *) asSafeSQLString;
+- (NSString *) asSafeSQLLikeString;
 
 /* Unicode safety */
 - (NSString *) safeString;
@@ -63,15 +65,21 @@
 - (id) objectFromJSONString;
 
 /* bare email addresses */
+- (NSString *) mailDomain;
 - (NSString *) pureEMailAddress;
 
 - (NSString *) asQPSubjectString: (NSString *) encoding;
 
-- (NSRange) _rangeOfURLInRange: (NSRange) refRange;
-
 /* LDAP */
 - (BOOL) caseInsensitiveMatches: (NSString *) match;
 
+/* OpenSSL multiline DN */
+- (NSArray *) componentsFromMultilineDN;
+
+/* XSS protection */
+- (NSString *) removeHTMLTagsExceptAnchorTags;
+- (NSString *) stringWithoutHTMLInjection: (BOOL)stripHTMLCode;
+
 #ifndef GNUSTEP_BASE_LIBRARY
 - (BOOL) boolValue;
 #endif
@@ -87,6 +95,9 @@
 - (NSString *) encryptWithKey: (NSString *) theKey;
 - (NSString *) decryptWithKey: (NSString *) theKey;
 
+/* HTML */
+- (NSString *) cleanInvalidHTMLTags;
+
 @end
 
 #endif /* NSSTRING_URL_H */
