@@ -1,6 +1,6 @@
 /* SOGoAuthenticator.h - this file is part of SOGo
  *
- * Copyright (C) 2007-2010 Inverse inc.
+ * Copyright (C) 2007-2011 Inverse inc.
  *
  * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
  *
@@ -23,7 +23,6 @@
 #ifndef SOGOAUTHENTICATOR_H
 #define SOGOAUTHENTICATOR_H
 
-#import <Foundation/NSObject.h>
 
 @class NSString;
 @class SOGoUser;
@@ -34,7 +33,7 @@
 - (NSString *) passwordInContext: (WOContext *) context;
 - (SOGoUser *) userInContext: (WOContext *) context;
 - (NSString *) imapPasswordInContext: (WOContext *) context
-                           forServer: (NSString *) imapServer
+                              forURL: (NSURL *) server
                           forceRenew: (BOOL) renew;
 
 @end
