@@ -31,7 +31,6 @@
 
 @class NGImap4Connection;
 
-@class SOGoGroup;
 @class SOGoObject;
 @class SOGoUser;
 @class SOGoUserDefaults;
@@ -67,13 +66,6 @@
              withName: (NSString *) userName;
 - (id) userNamed: (NSString *) name;
 
-- (void) registerGroup: (SOGoGroup *) group
-              withName: (NSString *) groupName
-	      inDomain: (NSString *) domainName;
-
-- (id) groupNamed: (NSString *) groupName
-	 inDomain: (NSString *) domainName;
-
 - (void) registerIMAP4Connection: (NGImap4Connection *) connection
                           forKey: (NSString *) key;
 - (NGImap4Connection *) imap4ConnectionForKey: (NSString *) key;
@@ -114,6 +106,7 @@
 //
 // CAS support
 //
+- (NSString *) sha512HashTicket: (NSString* ) ticket;
 - (NSString *) CASTicketFromIdentifier: (NSString *) identifier;
 - (NSString *) CASSessionWithTicket: (NSString *) ticket;
 - (void) setCASSession: (NSString *) casSession
