@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2004-2005 SKYRIX Software AG
-  Copyright (C) 2006-2014 Inverse inc.
+  Copyright (C) 2006-2022 Inverse inc.
 
   This file is part of SOGo.
 
@@ -77,6 +77,9 @@
 - (id) folderPropertyValueInCategory: (NSString *) theKey
 			     forUser: (SOGoUser *) theUser;
 
+- (BOOL) synchronize;
+- (void) setSynchronize: (BOOL) new;
+
 /* lower level fetches */
 - (void) deleteEntriesWithIds: (NSArray *) ids;
 
@@ -93,7 +96,7 @@
 
 - (BOOL) folderIsMandatory;
 
-- (BOOL) create;
+- (NSException *) create;
 - (NSException *) delete;
 - (void) renameTo: (NSString *) newName;
 
@@ -128,8 +131,8 @@
 
 - (NSArray *) syncTokenFieldsWithProperties: (NSDictionary *) properties
                           matchingSyncToken: (NSString *) syncToken
-                                   fromDate: (NSCalendarDate *) theStartDate;
-
+                                   fromDate: (NSCalendarDate *) theStartDate
+                                initialLoad: (BOOL) initialLoadInProgress;
 
 /* multiget helper */
 - (WOResponse *) performMultigetInContext: (WOContext *) queryContext
