@@ -525,6 +525,8 @@
       markInstance.mark(this.$mailbox.getHighlightWords());
       data = dom.innerHTML;
       dom.remove();
+    } else if (encodeEntities) {
+      data = data.encodeEntities();
     }
 
     return data;
@@ -549,8 +551,8 @@
   Message.prototype.getHighlightFrom = function () {
     var i = 0;
     for (i = 0; i < this.from.length; i++) {
-      this.from[i].full = this.highlightSearchTerms(this.from[i].full, false);
-      this.from[i].name = this.highlightSearchTerms(this.from[i].name, false);
+      this.from[i].fullHighlighted = this.highlightSearchTerms(this.from[i].full, false);
+      this.from[i].nameHighlighted = this.highlightSearchTerms(this.from[i].name, false);
     }
 
     return this.from;
@@ -844,6 +846,10 @@
       if (match)
         data[param] = decodeURIComponent(match[1]);
     });
+    if ('html' == Message.$Preferences.defaults.SOGoMailComposeMessageType && data.text && data.text.length > 0) {
+      data.text = data.text.replace(/(\r\n|\n|\r)/g, '<br/>');
+    }
+      
     // Other Recipients
     _.forEach(['cc', 'bcc'], function (param) {
       var re = new RegExp(param + '=([^&]+)');
