@@ -16,7 +16,7 @@
       this.account = stateAccount;
       this.autocomplete = {to: {}, cc: {}, bcc: {}};
       this.autosave = null;
-      this.isFullscreen = false;
+      this.isFullscreen = (typeof screen.orientation !== 'undefined' && screen.orientation && 'portrait-primary' == screen.orientation.type);
       this.hideBcc = (stateMessage.editable.bcc.length === 0);
       this.hideCc = (stateMessage.editable.cc.length === 0);
       this.identities = stateAccount.identities;
@@ -27,6 +27,7 @@
       this.sendState = false;
       this.toggleFullscreen = toggleFullscreen;
       this.firstFocus = true;
+      this.editor = null;
 
       _initFileUploader();
 
@@ -251,6 +252,9 @@
     };
 
     this.send = function () {
+      if (this.editor && this.editor.component)
+        this.editor.component.onEditorChange(true); // Call onEditorChange on sgCkEditor component
+      
       this.sendState = 'sending';
       if (this.autosave)
         $timeout.cancel(this.autosave);
@@ -527,6 +531,7 @@
 
     this.onHTMLReady = function ($editor) {
       if (!this.isNew()) {
+        this.editor = $editor;
         onCompletePromise().then(function() {
           $editor.focus();
         });
