@@ -1,6 +1,7 @@
 /* -*- Mode: javascript; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 
 (function() {
+  /* jshint loopfunc: true */
   'use strict';
 
   /**
@@ -8,7 +9,7 @@
    * @constructor
    */
   function Preferences() {
-    var _this = this, defaultsElement, settingsElement, data;
+    var _this = this, defaultsElement, settingsElement, data, time;
 
     this.nextAlarm = null;
     this.nextInboxPoll = null;
@@ -52,6 +53,13 @@
       if (data.SOGoRememberLastModule)
         data.SOGoLoginModule = "Last";
 
+      data.SOGoMailAutoMarkAsReadDelay = parseInt(data.SOGoMailAutoMarkAsReadDelay) || 0;
+      data.SOGoMailAutoMarkAsReadEnabled = (data.SOGoMailAutoMarkAsReadDelay >= 0);
+      if (data.SOGoMailAutoMarkAsReadDelay > 0)
+        data.SOGoMailAutoMarkAsReadMode = 'delay';
+      else
+        data.SOGoMailAutoMarkAsReadMode = 'immediate';
+
       // Mail editor autosave is a number of minutes or 0 if disabled
       data.SOGoMailAutoSave = parseInt(data.SOGoMailAutoSave) || 0;
 
@@ -76,18 +84,19 @@
       if (data.Vacation) {
         if (data.Vacation.startDate)
           data.Vacation.startDate = new Date(parseInt(data.Vacation.startDate) * 1000);
-        else {
-          data.Vacation.startDateEnabled = 0;
-          data.Vacation.startDate = new Date();
-          data.Vacation.startDate = data.Vacation.startDate.beginOfDay();
-          data.Vacation.startDate.addDays(1);
-        }
+
         if (data.Vacation.endDate)
           data.Vacation.endDate = new Date(parseInt(data.Vacation.endDate) * 1000);
-        else {
-          data.Vacation.endDateEnabled = 0;
-          data.Vacation.endDate = new Date(data.Vacation.startDate.getTime());
-          data.Vacation.endDate.addDays(1);
+
+        if (data.Vacation.startTime) {
+          time = data.Vacation.startTime.split(':');
+          data.Vacation.startTime = new Date();
+          data.Vacation.startTime.setHours(parseInt(time[0]), parseInt(time[1]));
+        }
+        if (data.Vacation.endTime) {
+          time = data.Vacation.endTime.split(':');
+          data.Vacation.endTime = new Date();
+          data.Vacation.endTime.setHours(parseInt(time[0]), parseInt(time[1]));
         }
         if (data.Vacation.autoReplyEmailAddresses &&
             angular.isString(data.Vacation.autoReplyEmailAddresses) &&
@@ -96,22 +105,42 @@
       } else
         data.Vacation = {};
 
+      if (angular.isUndefined(data.Vacation.days))
+        data.Vacation.days = [];
+
       if ((angular.isUndefined(data.Vacation.autoReplyEmailAddresses) ||
           data.Vacation.autoReplyEmailAddresses.length == 0) &&
           angular.isDefined(window.defaultEmailAddresses))
-        data.Vacation.autoReplyEmailAddresses = window.defaultEmailAddresses;
+        data.Vacation.autoReplyEmailAddresses = window.defaultEmailAddresses.slice();
 
       if (angular.isUndefined(data.Vacation.daysBetweenResponse))
         data.Vacation.daysBetweenResponse = 7;
 
-      if (angular.isUndefined(data.Vacation.startDate)) {
+      if (angular.isUndefined(data.Vacation.startDate) || !data.Vacation.startDate) {
         data.Vacation.startDateEnabled = 0;
         data.Vacation.startDate = new Date();
+        data.Vacation.startDate = data.Vacation.startDate.beginOfDay();
+        data.Vacation.startDate.addDays(1);
       }
 
-      if (angular.isUndefined(data.Vacation.endDate)) {
+      if (angular.isUndefined(data.Vacation.endDate) || !data.Vacation.endDate) {
         data.Vacation.endDateEnabled = 0;
-        data.Vacation.endDate = new Date();
+        data.Vacation.endDate = new Date(data.Vacation.startDate.getTime());
+        data.Vacation.endDate.addDays(1);
+      }
+
+      if (angular.isUndefined(data.Vacation.startTime) || !data.Vacation.startTime) {
+        data.Vacation.startTimeEnabled = 0;
+        data.Vacation.startTime = new Date();
+        data.Vacation.startTime.setHours(parseInt(data.SOGoDayEndTime));
+        data.Vacation.startTime.setMinutes(0);
+      }
+
+      if (angular.isUndefined(data.Vacation.endTime) || !data.Vacation.endTime) {
+        data.Vacation.endTimeEnabled = 0;
+        data.Vacation.endTime = new Date();
+        data.Vacation.endTime.setHours(parseInt(data.SOGoDayStartTime));
+        data.Vacation.endTime.setMinutes(0);
       }
 
       if (data.Forward) {
@@ -121,6 +150,13 @@
           data.Forward.forwardAddress = [];
       }
 
+      if (data.Notification) {
+        if (angular.isString(data.Notification.notificationAddress))
+          data.Notification.notificationAddress = data.Notification.notificationAddress.split(/, */);
+        else if (!angular.isArray(data.Notification.notificationAddress))
+          data.Notification.notificationAddress = [];
+      }
+
       // Split calendar categories colors keys and values
       if (angular.isUndefined(data.SOGoCalendarCategories))
         data.SOGoCalendarCategories = [];
@@ -134,6 +170,39 @@
       else
         data.SOGoContactsCategories = _.compact(data.SOGoContactsCategories);
 
+      data.emailSeparatorKeys = [
+        9,   // $mdConstant.KEY_CODE.TAB,
+        13,  // $mdConstant.KEY_CODE.ENTER,
+        186, // $mdConstant.KEY_CODE.SEMICOLON
+        188  // $mdConstant.KEY_CODE.COMMA,
+      ];
+      if (data.LocaleCode) {
+        data.ckLocaleCode = data.LocaleCode.replace('_', '-').toLowerCase();
+        // Exceptions
+        switch (data.LocaleCode) {
+        case 'it':
+          // The Italian keyboard layout has the same keycode (186) for '@' and ';'; we remove the semicolon.
+          data.emailSeparatorKeys = [
+            9,   // $mdConstant.KEY_CODE.TAB,
+            13,  // $mdConstant.KEY_CODE.ENTER,
+            188  // $mdConstant.KEY_CODE.COMMA,
+          ];
+          break;
+        case 'ru':
+          // The Russian keyboard layout has the same keycode (186) for 'Ж' and ';'; we remove the semicolon.
+          // It also has the same keycode (188) for 'Б' and ','; we remove the comma.
+          data.emailSeparatorKeys = [
+            9,  // $mdConstant.KEY_CODE.TAB,
+            13  // $mdConstant.KEY_CODE.ENTER,
+          ];
+          break;
+        case 'sr_ME':
+        case 'sr_RS':
+          data.ckLocaleCode = 'sr-latn';
+          break;
+        }
+      }
+
       angular.extend(_this.defaults, data);
 
       // Configure date locale
@@ -179,8 +248,30 @@
         data = {};
       }
 
-      // We convert our PreventInvitationsWhitelist hash into a array of user
       if (data.Calendar) {
+
+        // When the Calendar settings include "AutoReloadedWebCalendars", reload the Web calendars
+        // marked to be reloaded on login (AutoReloadedWebCalendars). Once completed, remove the
+        // parameter and save the settings.
+        if (data.Calendar.ReloadWebCalendars && data.Calendar.AutoReloadedWebCalendars) {
+          var reloadPromises = [];
+          _.map(data.Calendar.AutoReloadedWebCalendars, function (autoReload, id) {
+            if (autoReload) {
+              var calendarId = id.split('/')[1],
+                  deferred = Preferences.$q.defer();
+              Preferences.$$resource.quietFetch('Calendar/' + calendarId, 'reload').finally(deferred.resolve);
+              reloadPromises.push(deferred.promise);
+            }
+          });
+          Preferences.$q.all(reloadPromises).then(function() {
+            delete _this.settings.Calendar.ReloadWebCalendars;
+            Preferences.$$resource.save("Preferences", { settings: _this.$omit(true).settings }).then(function () {
+              Preferences.$rootScope.$emit('calendars:list');
+            });
+          });
+        }
+
+        // We convert our PreventInvitationsWhitelist hash into a array of user
         if (data.Calendar.PreventInvitationsWhitelist) {
           data.Calendar.PreventInvitationsWhitelist = _.map(data.Calendar.PreventInvitationsWhitelist, function(value, key) {
             var match = /^(.+)\s<(\S+)>$/.exec(value),
@@ -203,10 +294,11 @@
    * @desc The factory we'll use to register with Angular
    * @returns the Preferences constructor
    */
-  Preferences.$factory = ['$window', '$document', '$q', '$timeout', '$log', '$state', '$mdDateLocale', '$mdToast', 'sgSettings', 'Gravatar', 'Resource', 'User', function($window, $document, $q, $timeout, $log, $state, $mdDateLocaleProvider, $mdToast, Settings, Gravatar, Resource, User) {
+  Preferences.$factory = ['$window', '$document', '$rootScope', '$q', '$timeout', '$log', '$state', '$mdDateLocale', '$mdToast', 'sgConstant', 'sgSettings', 'Gravatar', 'Resource', 'User', function($window, $document, $rootScope, $q, $timeout, $log, $state, $mdDateLocaleProvider, $mdToast, sgConstant, Settings, Gravatar, Resource, User) {
     angular.extend(Preferences, {
       $window: $window,
       $document: $document,
+      $rootScope: $rootScope,
       $q: $q,
       $timeout: $timeout,
       $log: $log,
@@ -216,7 +308,8 @@
       $gravatar: Gravatar,
       $$resource: new Resource(Settings.activeUser('folderURL'), Settings.activeUser()),
       $resourcesURL: Settings.resourcesURL(),
-      $User: User
+      $User: User,
+      $sgConstant: sgConstant
     });
 
     return new Preferences(); // return unique instance
@@ -307,6 +400,26 @@
     return true;
   };
 
+  /**
+   * @function isItemSecretQuestion
+   * @memberof Preferences.prototype
+   * @desc Check if the customer pick the secret question for e-mail recovery
+   * @returns true if secret question is selected
+   */
+  Preferences.prototype.isItemSecretQuestion = function() {
+    return "SecretQuestion" == this.defaults.SOGoPasswordRecoveryMode;
+  };
+
+  /**
+   * @function isItemSecondaryEmail
+   * @memberof Preferences.prototype
+   * @desc Check if the customer pick the email for password recovery
+   * @returns true if email is selected
+   */
+  Preferences.prototype.isItemSecondaryEmail = function () {
+    return "SecondaryEmail" == this.defaults.SOGoPasswordRecoveryMode;
+  };
+
   /**
    * @function authorizeNotifications
    * @memberof Preferences.prototype
@@ -386,47 +499,73 @@
     if (this.nextInboxPoll)
       Preferences.$timeout.cancel(this.nextInboxPoll);
 
-    Preferences.$$resource.post('Mail', '0/folderINBOX/view', params).then(function(data) {
-      var uids = data.uids;
-      var uidHeaderIndex = data.headers[0].indexOf('uid');
-      var fromHeaderIndex = data.headers[0].indexOf('From');
-      var subjectHeaderIndex = data.headers[0].indexOf('Subject');
-      if (data.threaded) {
-        data.uids.splice(0, 1);
-        uids = _.map(data.uids, 0);
+    if (this.inboxSyncToken)
+      params.syncToken = this.inboxSyncToken;
+
+    /**
+     * @ngInject
+     */
+    toastController.$inject = ['scope', '$mdToast', 'title', 'body'];
+    function toastController (scope, $mdToast, title, body) {
+      scope.title = title;
+      scope.body = body;
+      scope.close = function() {
+        $mdToast.hide('ok');
+      };
+    }
+
+    return Preferences.$$resource.post('Mail', '0/folderINBOX/changes', params).then(function(data) {
+      if (data.syncToken) {
+        _this.inboxSyncToken = data.syncToken;
+        Preferences.$log.debug("New syncToken is " + _this.inboxSyncToken);
       }
-      if (_this.lastUid) {
-        _.find(uids, function (uid, index) {
-          var headers, id, href, toast;
-          if (uid > _this.lastUid) {
+
+      if (angular.isDefined(data.headers) && data.headers.length > 0) {
+        var uidHeaderIndex = data.headers[0].indexOf('uid');
+        var isReadHeaderIndex = data.headers[0].indexOf('isRead');
+        var fromHeaderIndex = data.headers[0].indexOf('From');
+        var subjectHeaderIndex = data.headers[0].indexOf('Subject');
+        var i;
+        var showToast = function() {
+          var _this = this;
+          return Preferences.$toast.show(this)
+            .then(function(response) {
+              if (response === 'ok') {
+                _this.viewInboxMessage(_this.locals.uid);
+              }
+            });
+        };
+        for (i = 1; i < data.headers.length; i++) {
+          var headers = data.headers[i],
+              uid = headers[uidHeaderIndex],
+              id, href, toast;
+          if (!headers[isReadHeaderIndex]) {
             // New unseen message
             Preferences.$log.debug('Show notification for message ' + uid);
-            headers = _.find(data.headers, function(h) {
-              return h[uidHeaderIndex] == uid;
-            });
             if (_this.defaults.SOGoDesktopNotifications) {
               id = 'mail-inbox-' + uid;
               href = Preferences.$state.href('mail.account.mailbox.message', { accountId: 0, mailboxId: 'INBOX', messageId: uid });
               _this.createNotification(id, headers[subjectHeaderIndex], {
                 body: headers[fromHeaderIndex][0].name || headers[fromHeaderIndex][0].email,
                 icon: '/SOGo.woa/WebServerResources/img/email-256px.png',
-                onClick: function () {
-                  _this.viewInboxMessage(uid);
-                }
+                onClick: angular.bind(_this, _this.viewInboxMessage, uid)
               });
             }
             else {
               toast = {
+                locals: {
+                  uid: uid,
+                  title: headers[subjectHeaderIndex],
+                  body: headers[fromHeaderIndex][0].name || headers[fromHeaderIndex][0].email
+                },
                 template: [
                   '<md-toast role="alert">',
                   '  <div class="md-toast-content">',
                   '    <div layout="row" layout-align="start center" flex>',
                   '      <md-icon class="md-primary md-hue-1">email</md-icon>',
                   '      <div class="sg-padded--left">',
-                  headers[subjectHeaderIndex],
-                  '        <div class="sg-hint">',
-                  headers[fromHeaderIndex][0].name || headers[fromHeaderIndex][0].email,
-                  '        </div>',
+                  '        <span md-truncate ng-bind="title"></span>',
+                  '        <div class="sg-hint" md-truncate ng-bind="body"></div>',
                   '      </div>',
                   '      <div flex></div>',
                   '      <md-button ng-click="close()">',
@@ -436,46 +575,21 @@
                   '  </div>',
                   '</md-toast>'
                 ].join(''),
-                position: 'top right',
+                position: Preferences.$sgConstant.toastPosition,
                 hideDelay: 5000,
-                controller: toastController
+                controller: toastController,
+                viewInboxMessage: _this.viewInboxMessage
               };
-              _this.currentToast = _this.currentToast.then(function () {
-                return Preferences.$toast.show(toast)
-                .then(function(response) {
-                  if (response === 'ok') {
-                    _this.viewInboxMessage(uid);
-                  }
-                });
-              });
+              _this.currentToast = _this.currentToast.then(angular.bind(toast, showToast));
             }
-            return false; // Continue to next unseen message
           }
-          else {
-            return true; // No more new messages
-          }
-        });
-        if (uids[0] > _this.lastUid) {
-          _this.lastUid = uids[0];
         }
-      } else {
-        _this.lastUid = uids[0];
       }
     }).finally(function () {
       var refreshViewCheck = _this.defaults.SOGoRefreshViewCheck;
       if (refreshViewCheck && refreshViewCheck != 'manually')
         _this.nextInboxPoll = Preferences.$timeout(angular.bind(_this, _this.pollInbox), refreshViewCheck.timeInterval()*1000);
     });
-
-    /**
-     * @ngInject
-     */
-    toastController.$inject = ['scope', '$mdToast'];
-    function toastController (scope, $mdToast) {
-      scope.close = function() {
-        $mdToast.hide('ok');
-      };
-    }
   };
 
   /**
@@ -562,7 +676,7 @@
       }
       _this.currentToast = _this.currentToast.then(function () {
         return Preferences.$toast.show({
-          position: 'top right',
+          position: Preferences.$sgConstant.toastPosition,
           hideDelay: 0,
           template: [
             '<md-toast>',
@@ -625,7 +739,7 @@
           Preferences.$toast.hide();
         };
         scope.snooze = function() {
-          Preferences.$$resource.fetch(url, 'view?snoozeAlarm=' + scope.reminder);
+          Preferences.$$resource.fetch('Calendar/' + url, 'view?snoozeAlarm=' + scope.reminder);
           Preferences.$toast.hide();
         };
       }
@@ -670,6 +784,18 @@
       }
     });
 
+    // Don't push locale definition
+    delete preferences.defaults.locale;
+
+    if (preferences.defaults.SOGoMailAutoMarkAsReadEnabled) {
+      if (preferences.defaults.SOGoMailAutoMarkAsReadMode == 'immediate')
+        preferences.defaults.SOGoMailAutoMarkAsReadDelay = 0;
+    } else {
+      preferences.defaults.SOGoMailAutoMarkAsReadDelay = -1;
+    }
+    delete preferences.defaults.SOGoMailAutoMarkAsReadEnabled;
+    delete preferences.defaults.SOGoMailAutoMarkAsReadMode;
+
     // Merge back mail labels keys and values
     preferences.defaults.SOGoMailLabelsColors = {};
     _.forEach(preferences.defaults.SOGoMailLabelsColorsKeys, function(key, i) {
@@ -687,6 +813,16 @@
       });
     });
 
+    // See Account.prototype.$omit
+    _.forEach(preferences.defaults.AuxiliaryMailAccounts, function (account) {
+      var identities = [];
+      _.forEach(account.identities, function (identity) {
+        if (!identity.isReadOnly)
+          identities.push(_.pick(identity, ['email', 'fullName', 'replyTo', 'signature', 'isDefault']));
+      });
+      account.identities = identities;
+    });
+
     if (!preferences.defaults.SOGoMailComposeWindowEnabled)
       delete preferences.defaults.SOGoMailComposeWindow;
     delete preferences.defaults.SOGoMailComposeWindowEnabled;
@@ -696,17 +832,35 @@
     delete preferences.defaults.SOGoMailComposeFontSizeEnabled;
 
     if (preferences.defaults.Vacation) {
-      if (preferences.defaults.Vacation.startDateEnabled)
+      if (preferences.defaults.Vacation.startDateEnabled) {
         preferences.defaults.Vacation.startDate = preferences.defaults.Vacation.startDate.getTime()/1000;
+      }
       else {
         delete preferences.defaults.Vacation.startDateEnabled;
-        preferences.defaults.Vacation.startDate = 0;
+        delete preferences.defaults.Vacation.startDate;
       }
       if (preferences.defaults.Vacation.endDateEnabled)
         preferences.defaults.Vacation.endDate = preferences.defaults.Vacation.endDate.getTime()/1000;
       else {
         delete preferences.defaults.Vacation.endDateEnabled;
-        preferences.defaults.Vacation.endDate = 0;
+        delete preferences.defaults.Vacation.endDate;
+      }
+
+      if (preferences.defaults.Vacation.startTimeEnabled) {
+        preferences.defaults.Vacation.startTime = preferences.defaults.Vacation.startTime.format(this.$mdDateLocaleProvider, '%H:%M');
+        // Set an end time only if a start time is defined
+        if (preferences.defaults.Vacation.endTimeEnabled)
+          preferences.defaults.Vacation.endTime = preferences.defaults.Vacation.endTime.format(this.$mdDateLocaleProvider, '%H:%M');
+        else {
+          delete preferences.defaults.Vacation.endTimeEnabled;
+          delete preferences.defaults.Vacation.endTime;
+        }
+      }
+      else {
+        delete preferences.defaults.Vacation.startTimeEnabled;
+        delete preferences.defaults.Vacation.startTime;
+        delete preferences.defaults.Vacation.endTimeEnabled;
+        delete preferences.defaults.Vacation.endTime;
       }
 
       if (preferences.defaults.Vacation.autoReplyEmailAddresses)
@@ -718,6 +872,9 @@
     if (preferences.defaults.Forward && preferences.defaults.Forward.forwardAddress)
       preferences.defaults.Forward.forwardAddress = _.compact(preferences.defaults.Forward.forwardAddress);
 
+      if (preferences.defaults.Notification && preferences.defaults.Notification.notificationAddress)
+      preferences.defaults.Notification.notificationAddress = _.compact(preferences.defaults.Notification.notificationAddress);
+
     // Merge back calendar categories colors keys and values
     preferences.defaults.SOGoCalendarCategoriesColors = {};
     _.forEach(preferences.defaults.SOGoCalendarCategories, function(key, i) {
