@@ -599,9 +599,9 @@
       this.repeat.end = 'never';
     this.$hasCustomRepeat = this.hasCustomRepeat();
 
+    var type = (this.type == 'appointment')? 'Events' : 'Tasks';
     if (this.isNew) {
       // Set default values
-      var type = (this.type == 'appointment')? 'Events' : 'Tasks';
 
       // Set default classification
       this.classification = Component.$Preferences.defaults['SOGoCalendar' + type + 'DefaultClassification'].toLowerCase();
@@ -618,8 +618,13 @@
       // Set notitifications
       this.sendAppointmentNotifications = Component.$Preferences.defaults.SOGoAppointmentSendEMailNotifications;
     }
-    else if (angular.isUndefined(data.$hasAlarm)) {
-      this.$hasAlarm = angular.isDefined(data.alarm);
+    else {
+      if (angular.isUndefined(data.$hasAlarm)) {
+        this.$hasAlarm = angular.isDefined(data.alarm);
+      }
+      if (angular.isUndefined(data.classification)) {
+        this.classification = Component.$Preferences.defaults['SOGoCalendar' + type + 'DefaultClassification'].toLowerCase();
+      }
     }
 
     // Allow the component to be moved to a different calendar
@@ -667,8 +672,8 @@
    * @desc Check if the component is editable and not an occurrence of a recurrent component
    * @returns true or false
    */
-  Component.prototype.isEditable = function() {
-    return (!this.occurrenceId && !this.isReadOnly);
+  Component.prototype.isActionable = function() {
+    return (!this.occurrenceId && !this.userHasRSVP && (this.isEditable || this.isErasable));
   };
 
   /**
@@ -677,8 +682,8 @@
    * @desc Check if the component is editable and an occurrence of a recurrent component
    * @returns true or false
    */
-  Component.prototype.isEditableOccurrence = function() {
-    return (this.occurrenceId && !this.isReadOnly);
+  Component.prototype.isActionableOccurrence = function() {
+    return (this.occurrenceId && !this.userHasRSVP && (this.isEditable || this.isErasable));
   };
 
   /**
@@ -701,18 +706,6 @@
     return (this.occurrenceId && this.userHasRSVP);
   };
 
-  /**
-   * @function isMovable
-   * @memberof Component.prototype
-   * @desc Return true if the component can be moved to a different calendar which occurs in two cases:
-   *       - the component is editable, ie is owned by the current user;
-   *       - the component is an invitation and the current user is an attendee.
-   * @returns true or false
-   */
-  Component.prototype.isMovable = function() {
-    return (!this.isReadOnly || this.userHasRSVP);
-  };
-
   /**
    * @function showPercentComplete
    * @memberof Component.prototype
@@ -805,7 +798,6 @@
    */
   Component.prototype.canRemindAttendeesByEmail = function() {
     return this.alarm.action == 'email' &&
-      !this.isReadOnly &&
       this.attendees && this.attendees.length > 0;
   };
 
@@ -1139,9 +1131,14 @@
    * @return a localized string
    */
   Component.prototype.repeatDescription = function() {
-    var localizedString = null;
-    if (this.repeat)
-      localizedString = l('repeat_' + this.repeat.frequency.toUpperCase());
+    var localizedString = null,
+        frequency;
+    if (this.repeat) {
+      frequency = this.repeat.frequency;
+      if (frequency == 'weekly' && this.repeat.interval == 2)
+        frequency = 'bi-weekly';
+      localizedString = l('repeat_' + frequency.toUpperCase());
+    }
 
     return localizedString;
   };
