@@ -230,7 +230,7 @@
       this.categories = {};
       this.showRecurrenceEditor = this.component.$hasCustomRepeat;
       this.showAttendeesEditor = this.component.attendees && this.component.attendees.length;
-      this.isFullscreen = false;
+      this.isFullscreen = (typeof screen.orientation !== 'undefined' && screen.orientation && 'portrait-primary' == screen.orientation.type);
       this.originalModalCancel = $mdDialog.cancel;
 
       if (this.component.type == 'appointment') {
@@ -328,12 +328,6 @@
         this.component.repeat.month.type == 'bymonthday';
     };
 
-    this.frequencies = function () {
-      return _.filter($window.repeatFrequencies, function (frequency) {
-        return frequency[0] != 'custom' || vm.component.repeat.frequency == 'custom';
-      });
-    };
-
     this.changeFrequency = function () {
       if (this.component.repeat.frequency == 'custom')
         this.showRecurrenceEditor = true;
@@ -557,10 +551,13 @@
               $mdDialog.cancel = vm.originalModalCancel;
               $mdDialog.hide();
             }, function(response) {
-              if (response.status == CalendarSettings.ConflictHTTPErrorCode)
+              vm.allowResubmit(form);
+
+              if (response.status == CalendarSettings.ConflictHTTPErrorCode) {
                 vm.attendeeConflictError = _.isObject(response.data.message) ? response.data.message : { reject: response.data.message };
-              else
+              } else {
                 vm.edit(form);
+              }
             });
         }
       });
@@ -594,6 +591,11 @@
       form.$setDirty();
     };
 
+    this.allowResubmit = function (form) {
+      form.$setPristine();
+      form.$setDirty();
+    };
+
     function getHours() {
       var hours = [];
       for (var i = 0; i <= 23; i++) {
